==> vtk6_6.2.0+dfsg1.orig.tar.xz: VTK-6.2.0/Rendering/FreeType/vtkFreeTypeStringToImage.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkFreeTypeStringToImage.cxx

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/

#include "vtkFreeTypeStringToImage.h"

#include "vtkStdString.h"
#include "vtkUnicodeString.h"
#include "vtkTextProperty.h"
#include "vtkVector.h"
#include "vtkImageData.h"

#include "vtkFreeTypeTools.h"

#include "vtkObjectFactory.h"

class vtkFreeTypeStringToImage::Internals
{
public:
  Internals()
    {
    this->FreeType = vtkFreeTypeTools::GetInstance();
    }
  vtkFreeTypeTools *FreeType;
};

//-----------------------------------------------------------------------------
vtkStandardNewMacro(vtkFreeTypeStringToImage);

//-----------------------------------------------------------------------------
vtkFreeTypeStringToImage::vtkFreeTypeStringToImage()
{
  this->Implementation = new Internals;
}

//-----------------------------------------------------------------------------
vtkFreeTypeStringToImage::~vtkFreeTypeStringToImage()
{
  delete this->Implementation;
}

//-----------------------------------------------------------------------------
vtkVector2i vtkFreeTypeStringToImage::GetBounds(vtkTextProperty *property,
                                                const vtkUnicodeString& string)
{
  int tmp[4] = { 0, 0, 0, 0 };
  vtkVector2i recti(tmp);
  if (!property)
    {
    return recti;
    }

  this->Implementation->FreeType->GetBoundingBox(property, string, tmp);

  recti.Set(tmp[1] - tmp[0],
            tmp[3] - tmp[2]);

  return recti;
}

//-----------------------------------------------------------------------------
vtkVector2i vtkFreeTypeStringToImage::GetBounds(vtkTextProperty *property,
                                                const vtkStdString& string)
{
  vtkVector2i recti(0, 0);
  int tmp[4];
  if (!property || string.empty())
    {
    return recti;
    }

  this->Implementation->FreeType->GetBoundingBox(property, string, tmp);

  recti.Set(tmp[1] - tmp[0],
            tmp[3] - tmp[2]);

  return recti;
}

//-----------------------------------------------------------------------------
int vtkFreeTypeStringToImage::RenderString(vtkTextProperty *property,
                                           const vtkUnicodeString& string,
                                           vtkImageData *data, int textDims[2])
{
  // Get the required size, and initialize a new QImage to draw on.
  vtkVector2i box = this->GetBounds(property, string);
  if (box.GetX() == 0 || box.GetY() == 0)
    {
    return 0;
    }

  return this->Implementation->FreeType->RenderString(property,
                                                      string,
                                                      data, textDims);
}

//-----------------------------------------------------------------------------
int vtkFreeTypeStringToImage::RenderString(vtkTextProperty *property,
                                           const vtkStdString& string,
                                           vtkImageData *data, int textDims[2])
{
  // Get the required size, and initialize a new QImage to draw on.
  vtkVector2i box = this->GetBounds(property, string);
  if (box.GetX() == 0 || box.GetY() == 0)
    {
    return 0;
    }

  return this->Implementation->FreeType->RenderString(property, string, data,
                                                      textDims);
}

//-----------------------------------------------------------------------------
void vtkFreeTypeStringToImage::SetScaleToPowerOfTwo(bool scale)
{
  this->vtkStringToImage::SetScaleToPowerOfTwo(scale);
  this->Implementation->FreeType->SetScaleToPowerTwo(scale);
}

//-----------------------------------------------------------------------------
void vtkFreeTypeStringToImage::DeepCopy(vtkFreeTypeStringToImage *)
{
}

//-----------------------------------------------------------------------------
void vtkFreeTypeStringToImage::PrintSelf(ostream &os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
}

==> vtk9_9.0.1+dfsg1.orig.tar.xz: VTK-9.0.1/Rendering/FreeType/vtkFreeTypeStringToImage.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkFreeTypeStringToImage.cxx

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/

#include "vtkFreeTypeStringToImage.h"

#include "vtkImageData.h"
#include "vtkStdString.h"
#include "vtkTextProperty.h"
#include "vtkUnicodeString.h"
#include "vtkVector.h"

#include "vtkFreeTypeTools.h"

#include "vtkObjectFactory.h"

class vtkFreeTypeStringToImage::Internals
{
public:
  Internals() { this->FreeType = vtkFreeTypeTools::GetInstance(); }
  vtkFreeTypeTools* FreeType;
};

//-----------------------------------------------------------------------------
vtkStandardNewMacro(vtkFreeTypeStringToImage);

//-----------------------------------------------------------------------------
vtkFreeTypeStringToImage::vtkFreeTypeStringToImage()
{
  this->Implementation = new Internals;
}

//-----------------------------------------------------------------------------
vtkFreeTypeStringToImage::~vtkFreeTypeStringToImage()
{
  delete this->Implementation;
}

//-----------------------------------------------------------------------------
vtkVector2i vtkFreeTypeStringToImage::GetBounds(
  vtkTextProperty* property, const vtkUnicodeString& string, int dpi)
{
  int tmp[4] = { 0, 0, 0, 0 };
  vtkVector2i recti(tmp);
  if (!property)
  {
    return recti;
  }

  this->Implementation->FreeType->GetBoundingBox(property, string, dpi, tmp);

  recti.Set(tmp[1] - tmp[0], tmp[3] - tmp[2]);

  return recti;
}

//-----------------------------------------------------------------------------
vtkVector2i vtkFreeTypeStringToImage::GetBounds(
  vtkTextProperty* property, const vtkStdString& string, int dpi)
{
  vtkVector2i recti(0, 0);
  int tmp[4];
  if (!property || string.empty())
  {
    return recti;
  }

  this->Implementation->FreeType->GetBoundingBox(property, string, dpi, tmp);

  recti.Set(tmp[1] - tmp[0], tmp[3] - tmp[2]);

  return recti;
}

//-----------------------------------------------------------------------------
int vtkFreeTypeStringToImage::RenderString(vtkTextProperty* property,
  const vtkUnicodeString& string, int dpi, vtkImageData* data, int textDims[2])
{
  return this->Implementation->FreeType->RenderString(property, string, dpi, data, textDims);
}

//-----------------------------------------------------------------------------
int vtkFreeTypeStringToImage::RenderString(vtkTextProperty* property, const vtkStdString& string,
  int dpi, vtkImageData* data, int textDims[2])
{
  return this->Implementation->FreeType->RenderString(property, string, dpi, data, textDims);
}

//-----------------------------------------------------------------------------
void vtkFreeTypeStringToImage::SetScaleToPowerOfTwo(bool scale)
{
  this->vtkStringToImage::SetScaleToPowerOfTwo(scale);
  this->Implementation->FreeType->SetScaleToPowerTwo(scale);
}

//-----------------------------------------------------------------------------
void vtkFreeTypeStringToImage::DeepCopy(vtkFreeTypeStringToImage*) {}

//-----------------------------------------------------------------------------
void vtkFreeTypeStringToImage::PrintSelf(ostream& os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
}
